pub type NonceSize<A, S> = <<A as AeadCore>::NonceSize as Sub<<S as StreamPrimitive<A>>::NonceOverhead>>::Output;Expand description
Size of a nonce as used by a STREAM construction, sans the overhead of the STREAM protocol itself.
pub type NonceSize<A, S> = <<A as AeadCore>::NonceSize as Sub<<S as StreamPrimitive<A>>::NonceOverhead>>::Output;Size of a nonce as used by a STREAM construction, sans the overhead of the STREAM protocol itself.